diff --git a/dumux/common/fixedlengthspline_.hh b/dumux/common/fixedlengthspline_.hh
index 5cc148e5bf5430268b6c9b2641bb6b96ef0c6618..748b9618cb8ac58bd36636b5a51981ac7551c84f 100644
--- a/dumux/common/fixedlengthspline_.hh
+++ b/dumux/common/fixedlengthspline_.hh
@@ -23,8 +23,6 @@
 #ifndef DUMUX_FIXED_LENGTH_SPLINE_HH
 #define DUMUX_FIXED_LENGTH_SPLINE_HH
 
-#include <tuple>
-
 #include <dune/common/fvector.hh>
 #include <dune/common/fmatrix.hh>
 #include <dune/istl/btdmatrix.hh>
@@ -186,8 +184,8 @@ public:
      * This method uses a single STL-compatible container of sampling
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
      * provide access to the x values via std::get<0>(obj) and to the
      * y value via std::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
      * provides a size() method. Also, the number of entries in the X
@@ -203,8 +201,8 @@ public:
         typename XYContainer::const_iterator it = points.begin();
         typename XYContainer::const_iterator endIt = points.end();
         for (int i = 0; it != endIt; ++i, ++it) {
-            xPos_[i] = std::get<0>(*it);
-            yPos_[i] = std::get<1>(*it);
+            xPos_[i] = Dune::get<0>(*it);
+            yPos_[i] = Dune::get<1>(*it);
         }
 
         // make a full spline
@@ -327,8 +325,8 @@ public:
      * This method uses a single STL-compatible container of sampling
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
      * provide access to the x values via std::get<0>(obj) and to the
      * y value via std::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
      * provides a size() method. Also, the number of entries in the X
@@ -342,8 +340,8 @@ public:
         typename XYContainer::const_iterator it = points.begin();
         typename XYContainer::const_iterator endIt = points.end();
         for (int i = 0; it != endIt; ++i, ++it) {
-            xPos_[i] = std::get<0>(*it);
-            yPos_[i] = std::get<1>(*it);
+            xPos_[i] = Dune::get<0>(*it);
+            yPos_[i] = Dune::get<1>(*it);
         }
 
         // make a natural spline
@@ -186,8 +184,8 @@ public:
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
-     * provide access to the x values via std::get<0>(obj) and to the
-     * y value via std::get<1>(obj) (e.g. std::tuple or
+     * provide access to the x values via Dune::get<0>(obj) and to the
+     * y value via Dune::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
@@ -327,8 +325,8 @@ public:
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
-     * provide access to the x values via std::get<0>(obj) and to the
-     * y value via std::get<1>(obj) (e.g. std::tuple or
+     * provide access to the x values via Dune::get<0>(obj) and to the
+     * y value via Dune::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
diff --git a/dumux/common/variablelengthspline_.hh b/dumux/common/variablelengthspline_.hh
index 80877c7cf2da470fc688fbcab24ee7290150c16d..2ec8457a04e567f9f8e08d2524d634c9fbf46354 100644
--- a/dumux/common/variablelengthspline_.hh
+++ b/dumux/common/variablelengthspline_.hh
@@ -186,8 +186,8 @@ public:
      * This method uses a single STL-compatible container of sampling
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
      * provide access to the x values via std::get<0>(obj) and to the
      * y value via std::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
      * provides a size() method. Also, the number of entries in the X
@@ -203,8 +203,8 @@ public:
         typename XYContainer::const_iterator it = points.begin();
         typename XYContainer::const_iterator endIt = points.end();
         for (int i = 0; it != endIt; ++i, ++it) {
-            xPos_[i] = std::get<0>(*it);
-            yPos_[i] = std::get<1>(*it);
+            xPos_[i] = Dune::get<0>(*it);
+            yPos_[i] = Dune::get<1>(*it);
         }
 
         // make a full spline
@@ -333,8 +333,8 @@ public:
      * This method uses a single STL-compatible container of sampling
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
      * provide access to the x values via std::get<0>(obj) and to the
      * y value via std::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
      * provides a size() method. Also, the number of entries in the X
@@ -348,8 +348,8 @@ public:
         typename XYContainer::const_iterator it = points.begin();
         typename XYContainer::const_iterator endIt = points.end();
         for (int i = 0; it != endIt; ++i, ++it) {
-            xPos_[i] = std::get<0>(*it);
-            yPos_[i] = std::get<1>(*it);
+            xPos_[i] = Dune::get<0>(*it);
+            yPos_[i] = Dune::get<1>(*it);
         }
 
         // make a natural spline
@@ -186,8 +186,8 @@ public:
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
-     * provide access to the x values via std::get<0>(obj) and to the
-     * y value via std::get<1>(obj) (e.g. std::tuple or
+     * provide access to the x values via Dune::get<0>(obj) and to the
+     * y value via Dune::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also
@@ -333,8 +333,8 @@ public:
      * points, which are assumed to be tuple-like objects storing the
      * X and Y coordinates.  "tuple-like" means that the objects
-     * provide access to the x values via std::get<0>(obj) and to the
-     * y value via std::get<1>(obj) (e.g. std::tuple or
+     * provide access to the x values via Dune::get<0>(obj) and to the
+     * y value via Dune::get<1>(obj) (e.g. std::tuple or
      * std::pair). "STL-compatible" means that the container provides
      * access to iterators using the begin(), end() methods and also